@@ -1,6 +1,5 @@
 # all the imports
-from flask import Flask, request, session, g, redirect, url_for, \
-     abort, render_template, flash
+from flask import Flask, render_template
 
 # configuration
 DEBUG = True
